%bcond_without check


%global goipath       github.com/influxdata/influxdb
%global influx_usr    influxdb
%global influx_grp    influxdb
%global influx_db_dir %{_sharedstatedir}/influxdb
%global golicenses    LICENSE
%global godocs        README.md

Version:        1.7.9

# Keep in sync Version and main_commit
%global main_commit   23bc63d43a8dc05f53afa46e3526ebb5578f3d88
%global main_branch   %(x=%{version}; [[ $x =~ ([0-9]+\.[0-9]+).* ]] && echo "${BASH_REMATCH[1]}")

%gometa

Name:           %{goname}
Release:        1%{?dist}
Summary:        Scalable datastore for metrics, events, and real-time analytics
License:        MIT
URL:            %{gourl}
Source0:        %{gosource}

BuildRequires:  /usr/bin/git
BuildRequires:  /usr/bin/bzr
BuildRequires:  /usr/bin/xmlto
BuildRequires:  /usr/bin/asciidoc
BuildRequires:  systemd
BuildRequires:  dep

Requires(pre):  shadow-utils

Obsoletes:      golang-github-influxdb-influxdb <= 0.9.5.1

%{?systemd_requires}

%description
InfluxDB is an open source time series database with no external dependencies.
It's useful for recording metrics, events, and performing analytics.

Features:
    - Built-in HTTP API so you don't have to write any server side code to get
      up and running.
    - Data can be tagged, allowing very flexible querying.
    - SQL-like query language.
    - Simple to install and manage, and fast to get data in and out.
    - It aims to answer queries in real-time. That means every data point is
      indexed as it comes in and is immediately available in queries that
      should return in < 100ms.


%prep
%forgeautosetup
%goprep


%build
(cd %{gobuilddir}/src/%{goipath} && GOPATH=%{gobuilddir} dep ensure -vendor-only)

export LDFLAGS="${LDFLAGS} -X main.version=%{version} -X main.branch=%{main_branch} -X main.commit=%{main_commit} "

for cmd in influx_stress influxd influx_inspect influx influx_tsm; do
    echo building ${cmd}
    %gobuild -o %{gobuilddir}/bin/$cmd %{goipath}/cmd/$cmd
done

# compile manuals
%make_build -C man build


%install
# install manuals
%make_install -C man DESTDIR=%{buildroot}%{_prefix}

# install binaries
install -p -m 0755 -d %{buildroot}%{_bindir}
install -p -m 0755 _build/bin/* %{buildroot}%{_bindir}/

# install configuration file
install -p -m 0644 -D etc/config.sample.toml %{buildroot}%{_sysconfdir}/influxdb/influxdb.conf

# install service file
install -p -m 0644 -D scripts/influxdb.service %{buildroot}%{_unitdir}/influxdb.service

# db home directory
install -d -m 0755 -d %{buildroot}%{influx_db_dir}


%if %{with check}
%check
%gocheck
%endif


%files
%license %{golicenses}
%doc %{godocs}
%{_bindir}/influx
%{_bindir}/influx_inspect
%{_bindir}/influx_stress
%{_bindir}/influx_tsm
%{_bindir}/influxd
%{_unitdir}/influxdb.service
%dir %{_sysconfdir}/influxdb
%config(noreplace) %{_sysconfdir}/influxdb/influxdb.conf
%{_mandir}/man1/influx.1*
%{_mandir}/man1/influx_inspect.1*
%{_mandir}/man1/influx_stress.1*
%{_mandir}/man1/influx_tsm.1*
%{_mandir}/man1/influxd.1*
%{_mandir}/man1/influxd-backup.1*
%{_mandir}/man1/influxd-config.1*
%{_mandir}/man1/influxd-restore.1*
%{_mandir}/man1/influxd-run.1*
%{_mandir}/man1/influxd-version.1*
%config(noreplace) %dir %attr(0755,%{influx_usr},influxdb) %{influx_db_dir}


%pre
getent group %{influx_grp} >/dev/null || groupadd -r %{influx_grp}
getent passwd %{influx_usr} >/dev/null || \
    useradd -r -g %{influx_grp} \
               -d %{influx_db_dir} \
               -s /sbin/nologin \
               -c "influxdb database user" \
               %{influx_usr}
exit 0


%post
%systemd_post influxdb.service


%preun
%systemd_preun influxdb.service


%postun
%systemd_postun_with_restart influxdb.service


%changelog
* Tue Feb 04 2020 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.9-1
- Update to the latest stable version

* Fri Aug 23 2019 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.7-3
- specify main.version

* Fri Aug 23 2019 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.7-2
- Update to the latest stable version

* Mon Jan 07 2019 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.2-4
- rebuilt

* Sun Jan 06 2019 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.2-3
- rebuilt

* Sun Jan 06 2019 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.2-2
- rebuilt

* Sun Jan 06 2019 Damian Wrobel <dwrobel@ertelnet.rybnik.pl> - 1.7.2-1
- First package for Fedora
